@@ -1,13 +1,12 @@
-# coding=utf-8
-""""""
-from __future__ import absolute_import, print_function, unicode_literals
+from typing import Any, Dict
+
+from flask import Blueprint as BaseBlueprint
+from flask import g
+from werkzeug.exceptions import NotFound
 
 from abilian.i18n import _l
 from abilian.web.action import Endpoint
 from abilian.web.nav import BreadcrumbItem
-from flask import Blueprint as BaseBlueprint
-from flask import g
-from werkzeug.exceptions import NotFound
 
 from . import security
 from .models import Community
@@ -24,7 +23,7 @@ class Blueprint(BaseBlueprint):
     _BASE_URL_PREFIX = "/communities"
     _ROUTE_PARAM = "<string:community_id>"
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args: str, **kwargs: Any) -> None:
         url_prefix = kwargs.get("url_prefix", "")
 
         if kwargs.pop("set_community_id_prefix", True):
@@ -47,18 +46,18 @@ class Blueprint(BaseBlueprint):
         self.before_request(check_access)
 
 
-def check_access():
+def check_access() -> None:
     if hasattr(g, "community"):
         # communities.index is not inside a community, for example
         security.check_access(g.community)
 
 
-def init_current_tab(endpoint, values):
+def init_current_tab(endpoint: str, values: Dict[str, int]) -> None:
     """Ensure g.current_tab exists."""
     g.current_tab = None
 
 
-def pull_community(endpoint, values):
+def pull_community(endpoint: str, values: Dict[str, Any]) -> None:
     """url_value_preprocessor function."""
     g.nav["active"] = "section:communities"
     g.breadcrumb.append(
