@@ -1,22 +1,20 @@
-# coding=utf-8
 # Note: this test suite is using pytest instead of the unittest-based scaffolding
 # provided by SBE. Hopefully one day all of SBE will follow.
 
-from __future__ import absolute_import, print_function, unicode_literals
-
 from datetime import datetime, timedelta
+from typing import Iterator, Union
+
+import pytest
 
 import abilian.i18n
-import pytest
 from abilian.core.signals import activity
-
-from abilian.sbe.app import create_app
+from abilian.sbe.app import Application, create_app
 from abilian.sbe.apps.communities.common import activity_time_format
 
 
 @pytest.fixture
-def app():
-    app = create_app()
+def app(config: type) -> Iterator[Union[Iterator, Iterator[Application]]]:
+    app = create_app(config)
 
     # We need some incantations here to make babel work in the test
     babel = abilian.i18n.babel
@@ -29,7 +27,7 @@ def app():
     activity._clear_state()
 
 
-def test_activity_time_format(app):
+def test_activity_time_format(app: Application) -> None:
     # We need the app context because of Babel.
 
     with app.app_context():
