@@ -1,5 +1,2 @@
-# coding=utf-8
-from __future__ import absolute_import
-
 from . import views, wizard  # noqa
 from .views import BaseCommunityView, communities, default_view_kw, tab  # noqa
