@@ -1,18 +1,16 @@
-# coding=utf-8
 """Folders / Documents module."""
-from __future__ import absolute_import
+import typing
 
-from abilian.sbe.extension import sbe
+if typing.TYPE_CHECKING:
+    from abilian.sbe.app import Application
 
 
-def register_plugin(app):
-    sbe.init_app(app)
-
-    from .views import blueprint
-    from .models import setup_listener
-    from .commands import manager  # pylint: disable=bad-python3-import
+def register_plugin(app: "Application") -> None:
     from . import signals  # noqa
     from . import lock
+    from .cli import antivirus
+    from .models import setup_listener
+    from .views import blueprint
 
     app.register_blueprint(blueprint)
     setup_listener()
@@ -20,5 +18,4 @@ def register_plugin(app):
     # set default lock lifetime
     app.config.setdefault("SBE_LOCK_LIFETIME", lock.DEFAULT_LIFETIME)
 
-    if app.script_manager:
-        app.script_manager.add_command("documents", manager)
+    app.cli.add_command(antivirus)
