@@ -1,16 +1,14 @@
-# coding=utf-8
-""""""
-from __future__ import absolute_import, print_function, unicode_literals
-
 from typing import Any, Dict
 
-from abilian.i18n import _l
-from abilian.services.security import MANAGE, WRITE, security
-from abilian.web.action import Action, FAIcon, ModalActionMixin, actions
 from flask import g
 from flask import url_for as url_for_orig
+from flask.blueprints import BlueprintSetupState
+from flask_login import current_user
 
+from abilian.i18n import _l
 from abilian.sbe.apps.communities.security import is_manager
+from abilian.services.security import MANAGE, WRITE, security
+from abilian.web.action import Action, FAIcon, ModalActionMixin, actions
 
 from .repository import repository
 
@@ -20,17 +18,16 @@ def url_for(endpoint, **kw):
 
 
 class CmisContentAction(Action):
-    sbe_type = None  # type: str
-    permission = None  # type: str
+    sbe_type: str = ""
+    permission: str = ""
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         if "permission" in kwargs:
             self.permission = kwargs.pop("permission")
 
         Action.__init__(self, *args, **kwargs)
 
-    def pre_condition(self, ctx):
-        # type: (Dict[str, Any]) -> bool
+    def pre_condition(self, ctx: Dict[str, Any]) -> bool:
         obj = ctx["object"]
         ok = obj.sbe_type == self.sbe_type
 
@@ -39,9 +36,8 @@ class CmisContentAction(Action):
 
         return ok
 
-    def has_access(self, permission, obj):
-        # type: (str, Any) -> bool
-        return repository.has_permission(g.user, permission, obj)
+    def has_access(self, permission: str, obj: Any) -> bool:
+        return repository.has_permission(current_user, permission, obj)
 
 
 class BaseFolderAction(CmisContentAction):
@@ -64,7 +60,7 @@ class FolderButtonAction(BaseFolderAction):
         "{{ action.icon }}</a>"
     )
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         self.modal = False
 
         if "modal" in kwargs:
@@ -87,8 +83,7 @@ class FolderAction(BaseFolderAction):
 
     def pre_condition(self, ctx):
         return (
-            super(FolderAction, self).pre_condition(ctx)
-            and ctx["object"] is not repository.root_folder
+            super().pre_condition(ctx) and ctx["object"] is not repository.root_folder
         )
 
 
@@ -183,7 +178,7 @@ _actions = (
         "view",
         _l("List content"),
         icon="list",
-        condition=(lambda ctx: security.has_role(g.user, "admin")),
+        condition=(lambda ctx: security.has_role(current_user, "admin")),
         url=lambda ctx: url_for(".folder_view", folder_id=ctx["object"].id),
     ),
     # view
@@ -343,7 +338,7 @@ _actions = (
 )
 
 
-def register_actions(state):
+def register_actions(state: BlueprintSetupState) -> None:
     if not actions.installed(state.app):
         return
 
