@@ -1,25 +1,25 @@
-# coding=utf-8
-
-from __future__ import absolute_import, print_function, unicode_literals
+from typing import Union
 
+from flask.ctx import AppContext
 from pytest import fixture
+from sqlalchemy.orm import Session
 
-from abilian.sbe.app import create_app
+from abilian.sbe.app import Application, create_app
 from abilian.sbe.apps.documents.models import Document, Folder, icon_for
 
 
 @fixture
-def app(config):
+def app(config: type) -> Application:
     return create_app(config=config)
 
 
-def check_editable(object):
+def check_editable(object: Union[Document, Folder]) -> None:
     if hasattr(object, "__editable__"):
         for k in object.__editable__:
             assert hasattr(object, k)
 
 
-def test_title_prevails():
+def test_title_prevails() -> None:
     f = Folder(name="name", title="title")
     assert f.title == "title"
     assert f.name == "title"
@@ -33,12 +33,12 @@ def test_title_prevails():
     assert f.name == "name"
 
 
-def test_folder_editables():
+def test_folder_editables() -> None:
     root = Folder(title="/")
     check_editable(root)
 
 
-def test_folder_can_create_documents():
+def test_folder_can_create_documents() -> None:
     root = Folder(title="/")
 
     document = root.create_document("doc")
@@ -51,7 +51,7 @@ def test_folder_can_create_documents():
     assert document.parent == root
 
 
-def test_folder_can_create_subfolders():
+def test_folder_can_create_subfolders() -> None:
     root = Folder(title="/")
 
     subfolder = root.create_subfolder("folder")
@@ -63,7 +63,7 @@ def test_folder_can_create_subfolders():
     assert subfolder.parent == root
 
 
-def test_nested_subobjects():
+def test_nested_subobjects() -> None:
     root = Folder(title="/")
     subfolder = root.create_subfolder("folder1")
     subsubfolder = subfolder.create_subfolder("folder2")
@@ -81,7 +81,7 @@ def test_nested_subobjects():
     assert root.get_object_by_path("/folder1/doc") == document
 
 
-def test_folder_is_clonable():
+def test_folder_is_clonable() -> None:
     root = Folder(title="/")
     clone = root.clone()
 
@@ -89,18 +89,18 @@ def test_folder_is_clonable():
     assert clone.path == root.path
 
 
-def test_document_editables():
+def test_document_editables() -> None:
     doc = Document()
     check_editable(doc)
 
 
-def test_content_length(session):
+def test_content_length(session: Session) -> None:
     doc = Document(title="toto")
     doc.set_content(b"tototiti", "application/binary")
     assert doc.content_length == len("tototiti")
 
 
-def test_document_is_clonable(session):
+def test_document_is_clonable(session: Session) -> None:
     root = Folder(title="/")
     doc = root.create_document(title="toto")
     doc.content = b"tototiti"
@@ -110,7 +110,7 @@ def test_document_is_clonable(session):
     assert clone.content == doc.content
 
 
-def test_document_has_an_icon(app_context):
+def test_document_has_an_icon(app_context: AppContext) -> None:
     root = Folder(title="/")
     doc = root.create_document(title="toto")
     doc.content_type = "image/jpeg"
@@ -118,7 +118,7 @@ def test_document_has_an_icon(app_context):
     assert filename in ("jpg.png", "jpeg.png"), doc.icon
 
 
-def test_icon_from_mime_type(app_context):
+def test_icon_from_mime_type(app_context: AppContext) -> None:
     icon = icon_for("text/html")
     filename = icon.split("/")[-1]
     assert filename in ("html.png", "htm.png"), icon
