@@ -1,7 +1,4 @@
-# coding=utf-8
-from __future__ import absolute_import, print_function, unicode_literals
-
-from ..cmis.parser import Entry
+from abilian.sbe.apps.documents.cmis.parser import Entry
 
 XML_ENTRY = b"""\
 <?xml version="1.0" encoding="utf-8"?>
@@ -47,13 +44,13 @@ XML_ENTRY_WITH_CONTENT = b"""\
 """
 
 
-def test_parse_folder_entry():
+def test_parse_folder_entry() -> None:
     e = Entry(XML_ENTRY)
     assert e.name == "Toto Titi"
     assert e.type == "cmis:folder"
 
 
-def test_parse_document_entry():
+def test_parse_document_entry() -> None:
     e = Entry(XML_ENTRY_WITH_CONTENT)
     assert e.name == "testDocument"
     assert e.type == "cmis:document"
