@@ -1,34 +1,30 @@
-# coding=utf-8
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 from pathlib import Path
 
 from lxml import etree
 
-from ..webdav.constants import DAV_PROPS
-from ..webdav.xml import MultiStatus, Propfind
+from abilian.sbe.apps.documents.webdav.constants import DAV_PROPS
+from abilian.sbe.apps.documents.webdav.xml import MultiStatus, Propfind
 
 
-def test_propfind_sample1():
+def test_propfind_sample1() -> None:
     xml = (Path(__file__).parent / "data" / "propfind1.xml").open("rb").read()
     propfind = Propfind(xml)
     assert propfind.mode == "prop"
 
 
-def test_propfind_sample2():
+def test_propfind_sample2() -> None:
     xml = (Path(__file__).parent / "data" / "propfind2.xml").open("rb").read()
     propfind = Propfind(xml)
     assert propfind.mode == "prop"
 
 
-def test_propfind_sample3():
+def test_propfind_sample3() -> None:
     xml = (Path(__file__).parent / "data" / "propfind3.xml").open("rb").read()
     propfind = Propfind(xml)
     assert propfind.mode == "allprop"
 
 
-def test_empty_multistatus():
+def test_empty_multistatus() -> None:
     m = MultiStatus()
     result = m.to_string()
 
@@ -36,13 +32,12 @@ def test_empty_multistatus():
     etree.fromstring(result)
 
 
-def test_multistatus():
-    class Obj(object):
-        pass
+def test_multistatus() -> None:
+    class Obj:
+        name = "some name"
+        is_folder = True
 
     obj = Obj()
-    obj.name = "some name"
-    obj.is_folder = True
     m = MultiStatus()
     m.add_response_for("http://example.com/", obj, DAV_PROPS)
     result = m.to_string()
