@@ -1,7 +1,3 @@
-# coding=utf-8
-""""""
-from __future__ import absolute_import, print_function, unicode_literals
-
 import fnmatch
 import itertools
 import logging
@@ -11,34 +7,37 @@ import tempfile
 from datetime import datetime
 from functools import partial
 from io import StringIO
-from typing import Any, List
+from typing import IO, Any, Dict, Iterator, List, Tuple
+from urllib.parse import quote
 from zipfile import ZipFile, is_zipfile
 
 import sqlalchemy as sa
 import whoosh.query as wq
+from flask import Markup, current_app, flash, g, jsonify, make_response, \
+    redirect, render_template, render_template_string, request, send_file, \
+    session
+from flask_login import current_user
+from sqlalchemy import func
+from werkzeug.datastructures import FileStorage
+from werkzeug.exceptions import InternalServerError
+from werkzeug.wrappers import Response
+from xlwt import Workbook, easyxf
+
 from abilian.core.extensions import db
 from abilian.core.models.subjects import Group, User
 from abilian.core.signals import activity
 from abilian.core.util import unwrap
 from abilian.i18n import _, _n
+from abilian.sbe.apps.communities.views import default_view_kw
+from abilian.sbe.apps.documents.models import Document, Folder, icon_for, \
+    icon_url
+from abilian.sbe.apps.documents.repository import repository
+from abilian.sbe.apps.documents.search import reindex_tree
 from abilian.services import get_service
 from abilian.services.security import READ, WRITE, Role, security
 from abilian.web import csrf, http, url_for
 from abilian.web.action import actions
 from abilian.web.views import default_view
-from flask import Markup, current_app, flash, g, jsonify, make_response, \
-    redirect, render_template, render_template_string, request, send_file, \
-    session
-from six import text_type
-from six.moves.urllib.parse import quote
-from sqlalchemy import func
-from werkzeug.exceptions import InternalServerError
-from xlwt import Workbook, easyxf
-
-from abilian.sbe.apps.communities.views import default_view_kw
-from abilian.sbe.apps.documents.models import Document, Folder, icon_for, icon_url
-from abilian.sbe.apps.documents.repository import repository
-from abilian.sbe.apps.documents.search import reindex_tree
 
 from .util import breadcrumbs_for, check_manage_access, check_read_access, \
     check_write_access, create_document, edit_object, get_document, \
@@ -51,7 +50,7 @@ __all__ = ()
 
 
 @route("/")
-def index():
+def index() -> Response:
     folder = g.community.folder
     url = url_for(folder)
     return redirect(url)
@@ -108,12 +107,16 @@ def folder_json(folder_id):
     result = {}
     has_permission = security.has_permission
     result["current_folder_selectable"] = has_permission(
-        g.user, WRITE, folder, inherit=True
+        current_user, WRITE, folder, inherit=True
     )
     folders = result["folders"] = []
     bc = result["breadcrumbs"] = []
     subfolders = sorted(
-        (f for f in folder.subfolders if has_permission(g.user, READ, f, inherit=True)),
+        (
+            f
+            for f in folder.subfolders
+            if has_permission(current_user, READ, f, inherit=True)
+        ),
         key=lambda f: f.title,
     )
 
@@ -198,7 +201,7 @@ def permissions(folder_id):
     query = query.order_by(func.lower(Group.name))
     all_groups = query.all()
 
-    class EntryPresenter(object):
+    class EntryPresenter:
         _USER_FMT = (
             '<a href="{{ url_for("social.user", user_id=user.id) }}">'
             "{{ user.name }}</a>"
@@ -230,7 +233,7 @@ def permissions(folder_id):
                     'On {date}, {manager} has revoked role "{role}" from ' "{principal}"
                 )
             else:
-                raise Exception("Unknown audit entry type %s" % e.op)
+                raise Exception(f"Unknown audit entry type {e.op}")
 
             principal = ""
             if self.entry.user:
@@ -274,7 +277,8 @@ def permissions_update(folder_id):
         inherit_security = action == "activate_inheritance"
 
         if not (
-            inherit_security or has_permission(g.user, "manage", folder, inherit=False)
+            inherit_security
+            or has_permission(current_user, "manage", folder, inherit=False)
         ):
             # don't let user shoot himself in the foot
             flash(
@@ -344,9 +348,9 @@ def permissions_update(folder_id):
             security.ungrant_role(user, role, folder)
 
             if (
-                user == g.user
+                user == current_user
                 and role == "manager"
-                and not has_permission(g.user, "manage", folder, inherit=True)
+                and not has_permission(current_user, "manage", folder, inherit=True)
             ):
 
                 transaction.rollback()
@@ -375,7 +379,7 @@ def permissions_update(folder_id):
             security.ungrant_role(group, role, folder)
 
             if role == "manager" and not has_permission(
-                g.user, "manage", folder, inherit=True
+                current_user, "manage", folder, inherit=True
             ):
                 transaction.rollback()
                 flash(
@@ -426,7 +430,7 @@ def permissions_export(folder_id):
 
     # styling
     # from xlwt doc: width unit is 1/256 of '0' from first font in excel file
-    for c, width in enumerate((c[1] for c in cols)):
+    for c, width in enumerate(c[1] for c in cols):
         if width is not None:
             ws.col(c).width = 256 * width
 
@@ -439,11 +443,11 @@ def permissions_export(folder_id):
     header_style = easyxf(
         "font: bold true;" "alignment: horizontal center, vertical center;"
     )
-    for c, val in enumerate((c[0] for c in cols)):
+    for c, val in enumerate(c[0] for c in cols):
         ws.write(0, c, val, header_style)
 
     # data
-    permissions = iter_permissions(folder, g.user)
+    permissions = iter_permissions(folder, current_user)
     row_offset = 0
     current_community = None
     for r, row in enumerate(permissions, 1):
@@ -459,7 +463,7 @@ def permissions_export(folder_id):
 
         for c, value in enumerate(row):
             if isinstance(value, Role):
-                value = text_type(value)
+                value = str(value)
             ws.write(r + row_offset, c, value)
 
         # data grouping exit
@@ -477,8 +481,8 @@ def permissions_export(folder_id):
     response.headers["content-type"] = "application/ms-excel"
     folder_name = folder.title.replace(" ", "_")
     file_date = datetime.now().strftime("%Y-%m-%d-%H:%M:%S")
-    filename = "permissions-{}-{}.xls".format(folder_name, file_date)
-    content_disposition = 'attachment;filename="{}"'.format(filename)
+    filename = f"permissions-{folder_name}-{file_date}.xls"
+    content_disposition = f'attachment;filename="{filename}"'
     response.headers["content-disposition"] = content_disposition
     return response
 
@@ -492,7 +496,7 @@ def iter_permissions(folder, user):
     community = folder.path
     local_roles = frozenset(folder.get_local_roles_assignments())
     inherited_roles = frozenset(
-        (folder.get_inherited_roles_assignments() if folder.inherit_security else [])
+        folder.get_inherited_roles_assignments() if folder.inherit_security else []
     )
 
     result = {}
@@ -505,7 +509,7 @@ def iter_permissions(folder, user):
         """Sorts by name, groups first."""
         principal = item[0][0]
         is_user = isinstance(principal, User)
-        item_key = [is_user]  # type: List[Any]
+        item_key: List[Any] = [is_user]
         if is_user:
             last_name = principal.last_name or ""
             first_name = principal.first_name or ""
@@ -540,8 +544,7 @@ def iter_permissions(folder, user):
     )
 
     for subfolder in subfolders:
-        for permission in iter_permissions(subfolder, user):
-            yield permission
+        yield from iter_permissions(subfolder, user)
 
 
 #
@@ -549,7 +552,7 @@ def iter_permissions(folder, user):
 #
 @route("/folder/<int:folder_id>", methods=["POST"])
 @csrf.protect
-def folder_post(folder_id):
+def folder_post(folder_id: int) -> Response:
     """A POST on a folder can result on several different actions (depending on
     the `action` parameter)."""
     folder = get_folder(folder_id)
@@ -610,7 +613,9 @@ ARCHIVE_IGNORE_FILES = {
 ARCHIVE_IGNORE_FILES.add(re.compile(fnmatch.translate("*/")))
 
 
-def explore_archive(fd, uncompress=False):
+def explore_archive(
+    fd: FileStorage, uncompress: bool = False
+) -> Iterator[Tuple[List[str], IO[bytes]]]:
     """Given an uploaded file descriptor, return it or a list of archive
     content.
 
@@ -649,19 +654,19 @@ def explore_archive(fd, uncompress=False):
             filepath = filename.split("/")
             filename = filepath.pop()
             zip_fd = archive.open(zipinfo, "r")
-            setattr(zip_fd, "filename", filename)
-            setattr(zip_fd, "content_type", None)
+            zip_fd.filename = filename
+            zip_fd.content_type = None
             yield filepath, zip_fd
 
 
-def upload_new(folder):
+def upload_new(folder: Folder) -> Response:
     check_write_access(folder)
     session = db.session()
     base_folder = folder
     uncompress_files = "uncompress_files" in request.form
     fds = request.files.getlist("file")
     created_count = 0
-    path_cache = {}  # mapping folder path in zip: folder instance
+    path_cache: Dict[str, Folder] = {}  # mapping folder path in zip -> folder instance
 
     for upload_fd in fds:
         for filepath, fd in explore_archive(upload_fd, uncompress=uncompress_files):
@@ -704,15 +709,15 @@ def upload_new(folder):
     return redirect(url_for(folder))
 
 
-def download_multiple(folder):
+def download_multiple(folder: Folder) -> Response:
     folders, docs = get_selected_objects(folder)
     if not folders:
         folders = [folder]
 
-    def rel_path(path, content):
-        return "{}/{}".format(path, content.title)
+    def rel_path(path: str, content: Document) -> str:
+        return f"{path}/{content.title}"
 
-    def zip_folder(zipfile, folder, path=""):
+    def zip_folder(zipfile: ZipFile, folder: Folder, path: str = "") -> ZipFile:
         for doc in folder.documents:
             doc_path = rel_path(path, doc)
             zipfile.writestr(doc_path, doc.content or b"")
@@ -759,7 +764,9 @@ def delete_multiple(folder):
     for obj in docs + folders:
         app = unwrap(current_app)
         community = g.community._model
-        activity.send(app, actor=g.user, verb="delete", object=obj, target=community)
+        activity.send(
+            app, actor=current_user, verb="delete", object=obj, target=community
+        )
         repository.delete_object(obj)
 
     if docs + folders:
@@ -790,9 +797,9 @@ def delete_multiple(folder):
     return redirect(url_for(folder))
 
 
-def move_multiple(folder):
+def move_multiple(folder: Folder) -> Response:
     folders, docs = get_selected_objects(folder)
-    objects = folder + docs
+    objects = folders + docs
 
     count_f = len(folders)
     count_d = len(docs)
@@ -803,7 +810,7 @@ def move_multiple(folder):
         return redirect(current_folder_url)
 
     try:
-        target_folder_id = int(request.form.get("target-folder"))
+        target_folder_id = int(request.form["target-folder"])
     except ValueError:
         flash(_("Move elements: no destination folder selected. Aborted."), "error")
         return redirect(current_folder_url)
@@ -820,12 +827,12 @@ def move_multiple(folder):
         )
         return redirect(current_folder_url)
 
-    if not security.has_permission(g.user, "write", folder, inherit=True):
+    if not security.has_permission(current_user, "write", folder, inherit=True):
         # this should not happen: this is just defensive programming
         flash(_("You are not allowed to move elements from this folder"), "error")
         return redirect(current_folder_url)
 
-    if not security.has_permission(g.user, "write", target_folder, inherit=True):
+    if not security.has_permission(current_user, "write", target_folder, inherit=True):
         flash(
             _('You are not allowed to write in folder "{folder}"').format(
                 folder=target_folder.title
@@ -861,7 +868,7 @@ def move_multiple(folder):
             "Move elements: canceled, some elements exists in destination "
             "folder: {elements}"
         )
-        elements = ", ".join('"{}"'.format(i.title) for i in exist_in_dest)
+        elements = ", ".join(f'"{i.title}"' for i in exist_in_dest)
         flash(msg.format(elements=elements), "error")
         return redirect(current_folder_url)
 
@@ -894,7 +901,7 @@ def objects_which_exist_in_dest(objects, dest):
     return exist_in_dest
 
 
-def create_subfolder(folder):
+def create_subfolder(folder: Folder) -> Response:
     check_write_access(folder)
 
     title = request.form.get("title", "")
@@ -964,7 +971,7 @@ def descendants_view(folder_id):
     bc = breadcrumbs_for(folder)
     actions.context["object"] = folder
 
-    root_path_ids = folder._indexable_parent_ids + "/{}".format(folder.id)
+    root_path_ids = folder._indexable_parent_ids + f"/{folder.id}"
     index_service = get_service("indexing")
 
     filters = wq.And(
@@ -1012,7 +1019,7 @@ def descendants_view(folder_id):
             descendants.append((level, type_letter, child))
 
             if is_folder:
-                path_id = child["parent_ids"] + "/{}".format(child["id"])
+                path_id = child["parent_ids"] + f"/{child['id']}"
                 visit(path_id, level + 1)
 
     visit(root_path_ids, 0)
