@@ -1,16 +1,14 @@
-# -*- coding: utf-8 -*-
 """Document management blueprint."""
-from __future__ import absolute_import, print_function, unicode_literals
+from typing import Dict
 
-from abilian.i18n import _l
-from abilian.web.action import Endpoint
-from abilian.web.nav import BreadcrumbItem
 from flask import g
 
+from abilian.i18n import _l
 from abilian.sbe.apps.communities.blueprint import Blueprint
 from abilian.sbe.apps.communities.security import is_manager
-
-from ..actions import register_actions
+from abilian.sbe.apps.documents.actions import register_actions
+from abilian.web.action import Endpoint
+from abilian.web.nav import BreadcrumbItem
 
 __all__ = ["blueprint"]
 
@@ -22,7 +20,7 @@ blueprint.record_once(register_actions)
 
 
 @blueprint.url_value_preprocessor
-def init_document_values(endpoint, values):
+def init_document_values(endpoint: str, values: Dict[str, int]) -> None:
     g.current_tab = "documents"
     g.is_manager = is_manager()
 
