@@ -1,11 +1,8 @@
-# coding=utf-8
 """Main views."""
 
-from __future__ import absolute_import, print_function, unicode_literals
-
 from flask import Blueprint, render_template
 
-__all__ = ()
+__all__ = ("blueprint",)
 
 blueprint = Blueprint("main", __name__, url_prefix="")
 route = blueprint.route
@@ -15,7 +12,7 @@ route = blueprint.route
 # Basic navigation
 #
 @route("/")
-def home():
+def home() -> str:
     return render_template("index.html")
 
 
