@@ -1,21 +1,18 @@
-# coding=utf-8
 """Notifications."""
-from __future__ import absolute_import, print_function, unicode_literals
 
-from abilian.sbe.extension import sbe
+from abilian.sbe.app import Application
 
 # Constants
 TOKEN_SERIALIZER_NAME = "unsubscribe_sbe"
 
 
-def register_plugin(app):
+def register_plugin(app: Application) -> None:
     cfg = app.config.setdefault("ABILIAN_SBE", {})
     cfg.setdefault("DAILY_SOCIAL_DIGEST_SUBJECT", "Des nouvelles de vos communautés")
-    sbe.init_app(app)
 
     # TODO: Slightly confusing. Reorg?
+    from .tasks.social import DEFAULT_DIGEST_SCHEDULE, DIGEST_TASK_NAME
     from .views import notifications, social  # noqa
-    from .tasks.social import DIGEST_TASK_NAME, DEFAULT_DIGEST_SCHEDULE
 
     CELERYBEAT_SCHEDULE = app.config.setdefault("CELERYBEAT_SCHEDULE", {})
 
