@@ -1,17 +1,15 @@
-# coding=utf-8
 """This panel manages user setting for email reminders related to the SBE
 (social netowking) app."""
-from __future__ import absolute_import, print_function, unicode_literals
+from flask import current_app as app
+from flask import flash, redirect, render_template, request, url_for
+from werkzeug.exceptions import Forbidden
+from wtforms import BooleanField
 
 from abilian.core.extensions import db
 from abilian.i18n import _, _l
 from abilian.services.preferences.panel import PreferencePanel
 from abilian.web import csrf
 from abilian.web.forms import Form, widgets
-from flask import current_app as app
-from flask import flash, redirect, render_template, request, url_for
-from werkzeug.exceptions import InternalServerError
-from wtforms import BooleanField
 
 
 class SbeNotificationsForm(Form):
@@ -25,13 +23,13 @@ class SbeNotificationsPanel(PreferencePanel):
     id = "sbe_notifications"
     label = _l("Community notifications")
 
-    def is_accessible(self):
+    def is_accessible(self) -> bool:
         return True
 
-    def get(self):
+    def get(self) -> str:
         # Manual security check, should be done by the framework instead.
         if not self.is_accessible():
-            raise InternalServerError()
+            raise Forbidden()
 
         preferences = app.services["preferences"]
         data = {}
@@ -48,7 +46,7 @@ class SbeNotificationsPanel(PreferencePanel):
     def post(self):
         # Manual security check, should be done by the framework instead.
         if not self.is_accessible():
-            raise InternalServerError()
+            raise Forbidden()
 
         if request.form["_action"] == "cancel":
             return redirect(url_for(".sbe_notifications"))
@@ -58,7 +56,7 @@ class SbeNotificationsPanel(PreferencePanel):
             for field_name, field in form._fields.items():
                 if field is form.csrf_token:
                     continue
-                key = "sbe:notifications:{}".format(field_name)
+                key = f"sbe:notifications:{field_name}"
                 value = field.data
                 preferences.set_preferences(**{key: value})
 
