@@ -1,18 +1,16 @@
-# coding=utf-8
 """
 NOTE: this code is a legacy from the early days of the application,
 and currently not used.
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
-
 import json
 
+from flask import Blueprint, make_response, request
+from flask_login import current_user, login_required
+
 from abilian.core.extensions import db
 from abilian.core.models.subjects import Group, User
 from abilian.core.util import get_params
-from flask import Blueprint, g, make_response, request
-from flask_login import login_required
 
 from .models import Message
 
@@ -58,8 +56,8 @@ def create_user():
 @login_required
 def list_users():
     # l = [ u.to_dict() for u in User.query.all() ]
-    l = list(User.query.all())
-    return make_json_response(l)
+    users = list(User.query.all())
+    return make_json_response(users)
 
 
 # [GET] /api/users/USER_ID	View User Profile
@@ -129,7 +127,7 @@ def get_followees(user_id):
 @login_required
 def follow(user_id):
     user = User.query.get(user_id)
-    g.user.follow(user)
+    current_user.follow(user)
     db.session.commit()
     return make_json_response("", 204)
 
@@ -141,7 +139,7 @@ def follow(user_id):
 @login_required
 def unfollow(user_id, contact_user_id):
     user = User.query.get(user_id)
-    g.user.unfollow(user)
+    current_user.unfollow(user)
     db.session.commit()
     return make_json_response("", 204)
 
@@ -155,8 +153,8 @@ def unfollow(user_id, contact_user_id):
 @restapi.route("/groups")
 @login_required
 def list_groups():
-    l = list(Group.query.all())
-    return make_json_response(l)
+    groups = list(Group.query.all())
+    return make_json_response(groups)
 
 
 # [GET] /api/groups/GROUP_ID	Show a Single Group
@@ -205,7 +203,7 @@ def create_group():
 @login_required
 def create_message():
     d = get_params(Message.__editable__)
-    message = Message(creator_id=g.user.id, **d)
+    message = Message(creator_id=current_user.id, **d)
     db.session.add(message)
     db.session.commit()
     return make_json_response(message, 201)
