@@ -1,15 +1,14 @@
-# coding=utf-8
 """Not used!"""
 
-from __future__ import absolute_import, print_function, unicode_literals
-
-from abilian.core.extensions import db, mail
-from flask import flash, g, redirect, render_template, request, url_for
+from flask import flash, redirect, render_template, request, url_for
 from flask_babel import gettext as _
+from flask_login import current_user
 from flask_mail import Message as Email
 from sqlalchemy.schema import Column
 from sqlalchemy.types import Text
 
+from abilian.core.extensions import db, mail
+
 from .social import social
 
 
@@ -44,15 +43,14 @@ def invite_post():
     with mail.connect() as conn:
         for email in emails:
             # FIXME: what do we do with this ?
-            invite = Invite(sender=g.user, email=email)  # noqa
+            invite = Invite(sender=current_user, email=email)  # noqa
 
             # subject = _(u"%s would like to invite you to the %s community")
-            # % (g.user.name, "Yaka")
-            subject = "%s would like to invite you to the %s community" % (
-                g.user.name,
-                "Yaka",
+            # % (current_user.name, "Yaka")
+            subject = "{} would like to invite you to the {} community".format(
+                current_user.name, "Yaka"
             )
-            msg = Email(subject, recipients=[email], sender=g.user.email)
+            msg = Email(subject, recipients=[email], sender=current_user.email)
             params = {"org_name": "Yaka"}
             msg.body = render_template("social/mail/invite.txt", **params)
             conn.send(msg)
