@@ -1,33 +1,29 @@
-# coding=utf-8
-""""""
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 import pkgutil
-from cgi import escape
+from html import escape
+from typing import Dict, List
 
 import sqlalchemy as sa
 import sqlalchemy.exc
 import sqlalchemy.orm
+from flask import Response, flash, jsonify, redirect, render_template, request
+from flask_login import current_user
+from sqlalchemy.sql.expression import and_, asc, desc, func, nullslast, or_
+from werkzeug.exceptions import InternalServerError
+
 from abilian.core.extensions import db
 from abilian.core.models.subjects import User
 from abilian.i18n import _, _l
+from abilian.sbe.apps.communities.models import Membership
+from abilian.sbe.apps.social.forms import UserProfileForm, UserProfileViewForm
+from abilian.sbe.apps.wall.presenters import ActivityEntryPresenter
+from abilian.sbe.apps.wall.views import get_recent_entries
 from abilian.services import get_service
 from abilian.web import url_for
 from abilian.web.filters import age
 from abilian.web.views import ObjectEdit, default_view
 from abilian.web.views.images import user_photo_url
-from flask import Response, flash, g, jsonify, redirect, render_template, \
-    request
-from six import text_type
-from sqlalchemy.sql.expression import and_, asc, desc, func, nullslast, or_
-from werkzeug.exceptions import InternalServerError
 
-from abilian.sbe.apps.communities.models import Membership
-from abilian.sbe.apps.wall.presenters import ActivityEntryPresenter
-from abilian.sbe.apps.wall.views import get_recent_entries
-
-from ..forms import UserProfileForm, UserProfileViewForm
 from .social import social
 
 logger = logging.getLogger(__name__)
@@ -37,7 +33,7 @@ DEFAULT_USER_MUGSHOT = pkgutil.get_data(
 )
 
 
-def make_tabs(user):
+def make_tabs(user: User) -> List[Dict[str, str]]:
     return [
         {"id": "profile", "label": _("Profile"), "link": url_for(user, tab="profile")},
         # dict(id='conversations', label=_(u'Conversations'), link=url_for(user), is_online=True),
@@ -52,7 +48,7 @@ def make_tabs(user):
 
 
 @social.route("/users/")
-def users():
+def users() -> str:
     query = request.args.get("query")
 
     if query:
@@ -123,7 +119,7 @@ def users_dt_json():
         # TODO: this should be done on the browser.
         user_url = url_for(".user", user_id=user.id)
         mugshot = user_photo_url(user, size=MUGSHOT_SIZE)
-        name = escape(getattr(user, "name") or "")
+        name = escape(user.name or "")
 
         cell0 = (
             '<a href="{url}"><img src="{src}" width="{size}" height="{size}">'
@@ -149,7 +145,7 @@ def users_dt_json():
 
 @social.route("/users/<int:user_id>")
 @default_view(social, User, "user_id")
-def user(user_id):
+def user(user_id: int) -> str:
     security = get_service("security")
     user = User.query.get(user_id)
 
@@ -157,9 +153,9 @@ def user(user_id):
     view_form = UserProfileViewForm(obj=user)
 
     communities = [m.community for m in user.communautes_membership]
-    if g.user != user and (not security.has_role(g.user, "manager")):
+    if current_user != user and (not security.has_role(current_user, "manager")):
         # filter visible communautes (ticket 165)
-        communities = [c for c in communities if c.has_member(g.user)]
+        communities = [c for c in communities if c.has_member(current_user)]
 
     view_form.communautes._set_data(communities)
 
@@ -178,13 +174,13 @@ def user(user_id):
     return render_template("social/user.html", **ctx)
 
 
-def can_edit(user):
+def can_edit(user: User) -> bool:
     security = get_service("security")
     if not security:
         return True
 
     # TODO: introduce a "self" role?
-    return (user == g.user) or security.has_role(g.user, "admin")
+    return (user == current_user) or security.has_role(current_user, "admin")
 
 
 class UserProfileEdit(ObjectEdit):
@@ -195,7 +191,7 @@ class UserProfileEdit(ObjectEdit):
     _message_success = _l("Profile edited")
 
     def init_object(self, args, kwargs):
-        args, kwargs = super(UserProfileEdit, self).init_object(args, kwargs)
+        args, kwargs = super().init_object(args, kwargs)
         self.user = self.obj
         return args, kwargs
 
@@ -205,7 +201,7 @@ class UserProfileEdit(ObjectEdit):
     def edit(self):
         if not can_edit(self.user):
             return Response(status=403)
-        return super(UserProfileEdit, self).edit()
+        return super().edit()
 
     def handle_commit_exception(self, exc):
         db.session.rollback()
@@ -228,9 +224,9 @@ def user_post(user_id):
     return_url = request.form.get("return_url")
 
     if action == "follow":
-        g.user.follow(user)
+        current_user.follow(user)
     elif action == "unfollow":
-        g.user.unfollow(user)
+        current_user.unfollow(user)
     else:
         raise Exception("Should not happen")
     db.session.commit()
@@ -294,11 +290,11 @@ def users_json():
             user, role = user
 
         if role is not None:
-            role = text_type(role)
+            role = str(role)
 
         item = {
             "id": user.id,
-            "text": "{} ({})".format(user.name, user.email),
+            "text": f"{user.name} ({user.email})",
             "name": user.name,
             "email": user.email,
             "role": role,
