@@ -1,22 +1,18 @@
-# coding=utf-8
-""""""
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
+from functools import singledispatch
 
 import bleach
-from abilian.core.util import BasePresenter
-from abilian.i18n import _, _l
-from abilian.web.util import url_for
 from flask import render_template_string
 from jinja2 import Markup, Template
-from singledispatch import singledispatch
 
+from abilian.core.util import BasePresenter
+from abilian.i18n import _, _l
 from abilian.sbe.apps.calendar.models import Event
 from abilian.sbe.apps.communities.models import Community
 from abilian.sbe.apps.documents.models import Document
 from abilian.sbe.apps.forum.models import Post, Thread
 from abilian.sbe.apps.wiki.models import WikiPage
+from abilian.web.util import url_for
 
 logger = logging.getLogger(__name__)
 
@@ -91,7 +87,7 @@ class ActivityEntryPresenter(BasePresenter):
     def object_url(self):
         return url_for(self._model.object)
 
-    def message(self, ignore_community=False):
+    def message(self, ignore_community=False) -> Markup:
         try:
             # another quick&dirty approach for now. FIXME later.
             entry = self._model
@@ -162,8 +158,7 @@ def get_body(object):
 
 
 @get_body.register(Thread)
-def get_body_thread(object):
-    # type: (Thread) -> Markup
+def get_body_thread(object: Thread) -> Markup:
     body = bleach.clean(object.posts[0].body_html, tags=[], strip=True)
     body = Markup(body).unescape()
     if len(body) > 400:
@@ -175,8 +170,7 @@ def get_body_thread(object):
 
 
 @get_body.register(Post)
-def get_body_post(object):
-    # type: (Post) -> Markup
+def get_body_post(object: Post) -> Markup:
     body = bleach.clean(object.body_html, tags=[], strip=True)
     body = Markup(body).unescape()
     if len(body) > 400:
@@ -188,8 +182,7 @@ def get_body_post(object):
 
 
 @get_body.register(Document)
-def get_body_document(object):
-    # type: (Document) -> Markup
+def get_body_document(object: Document) -> Markup:
     body = bleach.clean(object.body_html, tags=[], strip=True)
     body = Markup(body).unescape()
     if len(body) > 400:
