@@ -1,23 +1,19 @@
-# coding=utf-8
-""""""
-from __future__ import absolute_import, print_function, unicode_literals
-
 from datetime import date
 from itertools import groupby, islice
+from typing import Any, Dict
 
 import whoosh
 import whoosh.query as wq
-from abilian.services import get_service
-from abilian.web import url_for
-from abilian.web.action import actions
 from flask import current_app, g, render_template
 from flask_babel import format_date
-from six import text_type
 from sqlalchemy.orm import joinedload
 
 from abilian.sbe.apps.communities.blueprint import Blueprint
 from abilian.sbe.apps.documents.models import Document, icon_for
 from abilian.sbe.apps.forum.models import Thread
+from abilian.services import get_service
+from abilian.web import url_for
+from abilian.web.action import actions
 
 from .presenters import ActivityEntryPresenter
 from .util import get_recent_entries
@@ -27,12 +23,12 @@ route = wall.route
 
 
 @wall.url_value_preprocessor
-def set_current_tab(endpoint, values):
+def set_current_tab(endpoint: str, values: Dict[Any, Any]) -> None:
     g.current_tab = "wall"
 
 
 @route("/")
-def index():
+def index() -> str:
     actions.context["object"] = g.community._model
     entries = get_recent_entries(20, community=g.community)
     entries = ActivityEntryPresenter.wrap_collection(entries)
@@ -58,7 +54,7 @@ def files():
     return render_template("wall/files.html", grouped_docs=grouped_docs)
 
 
-class Attachment(object):
+class Attachment:
     def __init__(self, url, name, owner, date, content_length, content_type):
         self.url = url
         self.name = name
@@ -97,7 +93,7 @@ def get_attachments_from_forum(community):
             attachment = Attachment(
                 url,
                 att.name,
-                text_type(att.owner),
+                str(att.owner),
                 att.created_at,
                 att.content_length,
                 att.content_type,
@@ -144,7 +140,7 @@ def group_monthly(objects):
 
     def format_month(year, month):
         month = format_date(date(year, month, 1), "MMMM").capitalize()
-        return "%s %s" % (month, year)
+        return f"{month} {year}"
 
     grouped = groupby(objects, grouper)
     grouped = [
