@@ -1,21 +1,21 @@
-# coding=utf-8
-from __future__ import absolute_import, print_function, unicode_literals
+from typing import Any, Dict, cast
 
-from abilian.services import get_service
-from abilian.services.security import Admin
-from abilian.web.action import Action, FAIcon, ModalActionMixin, actions
 from flask import url_for
+from flask.blueprints import BlueprintSetupState
 from flask_babel import lazy_gettext as _l
 from flask_login import current_user
 
 from abilian.sbe.apps.communities.actions import CommunityEndpoint
 from abilian.sbe.apps.communities.security import is_manager
+from abilian.services import get_service
+from abilian.services.security import Admin, SecurityService
+from abilian.web.action import Action, FAIcon, ModalActionMixin, actions
 
 
 class WikiPageAction(Action):
     Endpoint = CommunityEndpoint
 
-    def pre_condition(self, context):
+    def pre_condition(self, context: Dict[str, Any]) -> bool:
         page = context.get("object")
         return bool(page)
 
@@ -30,7 +30,7 @@ class WikiPageAction(Action):
 
 
 def is_admin(context):
-    security = get_service("security")
+    security = cast(SecurityService, get_service("security"))
     return security.has_role(current_user, Admin, object=context.get("object"))
 
 
@@ -89,7 +89,7 @@ _actions = (
 )
 
 
-def register_actions(state):
+def register_actions(state: BlueprintSetupState) -> None:
     if not actions.installed(state.app):
         return
 
